`timescale 1ns / 1ps
////////////////////////////////////////////////////////////////////////////////  
// Module Name:    control4_6.v
// Project Name:   cpu
// Description:    This is a sample State Machine
// from control5s1.v Rev 26 July 2010
////////////////////////////////////////////////////////////////////////////////
module control4_6 (clk, rst, cntl, RE, BE, DAT, STAT);
   input         clk;
   input         rst;
   output  [2:0] cntl;
   output  [2:0] RE;
   output  [2:0] BE;
   output  [3:0] DAT;
   output  [3:0] STAT; // Current state identifier

   reg     [2:0] cntl;
   reg     [2:0] RE;
   reg     [2:0] BE;
   reg     [3:0] DAT;
   reg     [3:0] STAT;
   reg     [3:0] state;

   parameter S0 = 4'b0000;
   parameter S1 = 4'b0001;
   parameter S2 = 4'b0010;
   parameter S3 = 4'b0011;
   parameter S4 = 4'b0100;
	parameter S5 = 4'b0101;
	parameter S6 = 4'b0110;
	parameter S7 = 4'b0111;
	parameter S8 = 4'b1000;
	parameter S9 = 4'b1001;

always @ (posedge rst or negedge clk)
  if (rst)
// copy content of S0 from case statements, then change S0 : begin to begin
// also change state number to display from state to S0
//      S0 : begin // Load KP value #1 thru Buff0 into Reg0
//           STAT  <= state;  // state number to display
           begin // Load KP value #1 thru Buff0 into Reg0
           STAT  <= S0;     // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b001; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b001; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // AND (not used at this state)
           state <= S1;     // state to go to
           end
  else
    case (state)
      S0 : begin // Load KP value #1 thru Buff0 into Reg0
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b001; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b001; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // AND (not used at this state)
           state <= S1;     // state to go to
           end
      S1 : begin // Load KP value #2 thru Buff0 into Reg1
           STAT  <= state;
			  DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b001;
           RE    <= 3'b010;
           cntl  <= 3'b000; // AND (not used at this state)
           state <= S2;
           end
      S2 : begin // ADD Reg0 to Reg1 into Reg2 (sum of #1 + #2)
           STAT  <= state;
			  DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b000; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b100; // enable Reg2 to receive from ALU
           cntl  <= 3'b011; // ADD
			  state <= S3;
			  end
		S3 : begin // LOAD R2 thru B2 into R1. Verify R1 (sum of #1 + #2)
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b100; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b110; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // 
           state <= S4;
			  end
		S4 : begin // LOAD value #3 from the keyboard thru B0 into R0.
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b001; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b001; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // 
           state <= S5;
			  end
		S5 : begin // ADD R0 to R1 into R2. Verify R2 (sum of #1 + #2 + #3)
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b000; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b100; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b011; // 
           state <= S6;
			  end
		S6 : begin // AND R0 to R1 into R2. Verify R2 ( (sum of #1 + #2) AND with #3)
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b000; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b100; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // 
           state <= S7;
			  end
		S7 : begin // LOAD DATA "3" from the FSM into R1
           STAT  <= state;  // state number to display
           DAT   <= 4'b0011;// (not used at this state)
           BE    <= 3'b010; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b010; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b000; // 
           state <= S8;
			  end
		S8 : begin // LOAD R1 into R2 (B only). Verify R2 (value of DATA)
           STAT  <= state;  // state number to display
           DAT   <= 4'b0000;// (not used at this state)
           BE    <= 3'b000; // (Buff2, Buff1, Buff0) to be enabled (active hi)
           RE    <= 3'b100; // (Reg2, Reg1, Reg0)    to be clocked (active hi)
           cntl  <= 3'b010; // 
           state <= S9;
			  end
      S9 : begin // LOAD not (R1) into R2 (not B only).Verify R2 (value of not (DATA) ).
                 // When you get to S9, you have to display the final result and stay in
					  // this final state until the reset is pressed?in which case re-start
					  // the process from S0. The MUX, Z1, and 7seg columns are no longer used,
					  // so ignore them
           STAT <= state;  // stay in this state
			  DAT   <= 4'b0000;
			  BE    <= 3'b000;
			  RE    <= 3'b100;
			  cntl  <= 3'b110;
			  state <= S9;// stay in this state
           end
  endcase

endmodule