////////////////////////////////////////////////////////////////////////////////
// Module name: cpu4_6_sample.v
////////////////////////////////////////////////////////////////////////////////
module cpu4_6_sample
  (Master_clk, reset, PS2C, PS2D,
   HSYNC, VSYNC, RGB);

   input         Master_clk, reset, PS2C, PS2D;
   output        HSYNC, VSYNC;
   output  [7:0] RGB;

   // instantiate keyboard encoder module, needed wires first
   // wire          data_ready; //signal not used at this time
   wire    [7:0] scancode; // scancode from keyboard
   wire    [3:0] number4;  // scancode for 0 - 9, A - F converted to hex value
   wire          stopkey;  // pulses hi when keyboard key has been released, may replace db_clk
   //
   kbd_anton2 ENCODER
      (.Clk(Master_clk), .PS2_Clk(PS2C), .PS2_Data(PS2D),
       .data_ready(), .ps2_code(scancode),
       .number(number4), .stopkey(stopkey));

   // assign stopkey = BTN[0]; // use a button or switch for a temporary clock

   // cpu wiring
   wire [3:0] hexleft, gBus, A1, B1, C1, C2, D1, state;
   wire [2:0] buf_en;  // buf control
   wire [2:0] reg_en;  // reg control
   wire [2:0] reg_clk; // reg clock
   wire [2:0] cntl;    // alu control
   wire       CarryOut;
   assign hexleft = number4;
   assign db_clk  = stopkey; // use stopkey to replace db_clk
   assign dp      = stopkey; // state of db_clk

	//control4_6 (clk, rst, cntl, RE, BE, DAT, STAT);
   control4_6 CTRL (db_clk, reset, cntl, reg_en, buf_en, D1, state);
 
   assign reg_clk = reg_en & {db_clk, db_clk, db_clk}; // convert reg_en to rising clock
	//dff_4bit(clock, datain, dataout);
   dff_4bit REG0 (reg_clk[0], gBus, A1);
   dff_4bit REG1 (reg_clk[1], gBus, B1);
   dff_4bit REG2 (reg_clk[2], C1, C2);

	//bufe4 (enabl, din, dout);
   bufe4 BUF0 (buf_en[0], hexleft, gBus);
   bufe4 BUF1 (buf_en[1], D1, gBus);
   bufe4 BUF2 (buf_en[2], C2, gBus);
	//alu_4bit(op, a, b, CarryOut, ResultOut);
   alu_4bit ALU (cntl,A1,B1,CarryOut,C1);

   // vga interface simplified at this level
   vga_cpu4_6 VGA_cpu (Master_clk, reset, db_clk, CarryOut,
                       4'b0000, number4, 
                       hexleft, gBus, A1, B1, C1, C2, D1, 
                       Reg0, Reg1, Reg2, state, 
                       cntl, buf_en, reg_en, reg_clk, 
                       HSYNC, VSYNC, RGB);

endmodule
