`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Module Name:  hex_or_ascii.v
// Created 27 July 2009
// Translate hexidecimal input to ascii output, or copy input to output.
//    Input                      Output
//  8'h00->h0f : ascii_out <= 8'h30->h39,h41->h46; // hexidecimal 0 -> F
//     default : ascii_out <= hex_in; // otherwise, 8-bit ascii input assumed
//  default defined as normal ascii
//  8'h10->h2f : ascii_out <= 8'h10->h2f; // misc symbols
//  8'h30->h39 : ascii_out <= 8'h30->h39; // 0 -> 9
//  8'h3a->h40 : ascii_out <= 8'h3a->h40; // misc symbols
//  8'h41->h4f : ascii_out <= 8'h41->h4f; // A -> O
//  8'h50->h5a : ascii_out <= 8'h50->h5a; // P -> Z
//  8'h5b->h60 : ascii_out <= 8'h5b->h60; // misc symbols
//  8'h61->h6f : ascii_out <= 8'h61->h6f; // a -> o
//  8'h70->h7a : ascii_out <= 8'h70->h7a; // p -> z
//  8'h7b->h7f : ascii_out <= 8'h7b->h7f; // misc symbols
//  rev 04 July 2009  When highest bit is on, address is unmodified
//  8'h80->hff : ascii_out <= 8'h80->hff; // whole ascii set, address unmodified
//////////////////////////////////////////////////////////////////////////////////
module hex_or_ascii (hex_in, ascii_out);

    input [7:0] hex_in; // 8'hxx value to be converted
    output [7:0] ascii_out; // 8'hxx value once converted to ascii

reg [7:0] ascii_out;

always @(hex_in)
  case (hex_in)
    8'h00 : ascii_out <= 8'h30; // 0
    8'h01 : ascii_out <= 8'h31; // 1
    8'h02 : ascii_out <= 8'h32; // 2
    8'h03 : ascii_out <= 8'h33; // 3
    8'h04 : ascii_out <= 8'h34; // 4
    8'h05 : ascii_out <= 8'h35; // 5
    8'h06 : ascii_out <= 8'h36; // 6
    8'h07 : ascii_out <= 8'h37; // 7
    8'h08 : ascii_out <= 8'h38; // 8
    8'h09 : ascii_out <= 8'h39; // 9
    8'h0a : ascii_out <= 8'h41; // A
    8'h0b : ascii_out <= 8'h42; // B
    8'h0c : ascii_out <= 8'h43; // C
    8'h0d : ascii_out <= 8'h44; // D
    8'h0e : ascii_out <= 8'h45; // E
    8'h0f : ascii_out <= 8'h46; // F
//  default defined as normal ascii
    default : ascii_out <= hex_in; // 8-bit ascii input assumed
  endcase

endmodule
