////////////////////////////////////////////////////////////////////////////////
// Module name: text_40x15a.v
//  - ascii character display in 40 by 15 array
//  - scale 2x to 16-by-32 fonts
// (y_x) NUM coordinates (in decimal) start at top-left corner of display
// (h0_h0)   0,0 ..... 0,39   (h0_h27)
//            .  .....  .
//            .  .....  .
//            .  .....  .
// (he_h0)  14,0 .....14,39   (he_h27)
//
// Rev 04 Sep 2009
// Rev 07 Sep 2009 placed text coordinated with number locations
// Shifted display down 1 line with
//   assign cur40x15_y_x = {3'h0,pix_y[9:5]-1, 2'h0,pix_x[9:4]}; // padded to make coordinates byte-size
// Rev 08 Sep 2009 not use shift down 1 line for now
// Rev 05 Nov 09 color change moved from < 8'h30) to  < 8'h10) near bottom of file
////////////////////////////////////////////////////////////////////////////////
module text_40x15a
  (input  wire        clk,
   input  wire  [7:0] number,
   input  wire  [9:0] pix_x, pix_y,
   output wire [15:0] cur40x15_y_x,
   output wire        text_4x_on,
   output reg   [7:0] text_4x_rgb8
   );

   parameter xxx = 8'hff; // signifies no value at this location

   // signal declaration
   wire [10:0] rom_addr;
   reg   [7:0] char_addr;
   wire  [7:0] char_addr_tran;
   reg   [3:0] row_addr;
   reg   [2:0] bit_addr;
   wire  [7:0] font_word;
   wire        font_bit;

 //  - ascii character display in 20 by 7 array
 //  - scale 4x to 32-by-64 fonts
 //-----------------------------------------
   wire ascii_on;
   wire [3:0] row_addr_t;
   wire [2:0] bit_addr_t;
   reg  [7:0] char_addr_t; // the ascii value to be written
   assign ascii_on = (0<=pix_y[9:7]) && (pix_y[9:7]<=3) && // whole display area
                     (0<=pix_x[9:6]) && (pix_x[9:6]<=9);
//   assign row_addr_t = pix_y[5:2]; // 4x
//   assign bit_addr_t = pix_x[4:2];
   assign row_addr_t = pix_y[4:1]; // 2x
   assign bit_addr_t = pix_x[3:1];
//   assign cur20x7_y_x = {4'h0,pix_y[9:6], 3'h0,pix_x[9:5]}; // padded to make coordinates byte-size
   assign cur40x15_y_x = {3'h0,pix_y[9:5], 2'h0,pix_x[9:4]}; // padded to make coordinates byte-size
//   assign cur40x15_y_x = {3'h0,pix_y[9:5]-1, 2'h0,pix_x[9:4]}; // padded to make coordinates byte-size

   // write a value at any matching coordinate
   always @ *
   case (cur40x15_y_x)
   //  content of line 0
    16'h00_00 : char_addr_t <= number;
     16'h00_01 : char_addr_t <= number;
      16'h00_02 : char_addr_t <= number;
       16'h00_03 : char_addr_t <= number;
        16'h00_04 : char_addr_t <= number;
         16'h00_05 : char_addr_t <= number;
          16'h00_06 : char_addr_t <= number;
           16'h00_07 : char_addr_t <= number;
            16'h00_08 : char_addr_t <= number;
             16'h00_09 : char_addr_t <= number;
              16'h00_0a : char_addr_t <= number;
               16'h00_0b : char_addr_t <= number;
                16'h00_0c : char_addr_t <= number;
                 16'h00_0d : char_addr_t <= number;
                  16'h00_0e : char_addr_t <= number;
                   16'h00_0f : char_addr_t <= number;
                    16'h00_10 : char_addr_t <= number;
                     16'h00_11 : char_addr_t <= number;
                      16'h00_12 : char_addr_t <= number;
                       16'h00_13 : char_addr_t <= number;
                        16'h00_14 : char_addr_t <= number;
                         16'h00_15 : char_addr_t <= number;
                          16'h00_16 : char_addr_t <= number;
                           16'h00_17 : char_addr_t <= number;
                            16'h00_18 : char_addr_t <= number;
                             16'h00_19 : char_addr_t <= number;
                              16'h00_1a : char_addr_t <= number;
                               16'h00_1b : char_addr_t <= number;
                                16'h00_1c : char_addr_t <= number;
                                 16'h00_1d : char_addr_t <= number;
                                  16'h00_1e : char_addr_t <= number;
                                   16'h00_1f : char_addr_t <= number;
                                    16'h00_20 : char_addr_t <= number;
                                     16'h00_21 : char_addr_t <= number;
                                      16'h00_22 : char_addr_t <= number;
                                       16'h00_23 : char_addr_t <= number;
                                        16'h00_24 : char_addr_t <= number;
                                         16'h00_25 : char_addr_t <= number;
                                          16'h00_26 : char_addr_t <= number;
                                           16'h00_27 : char_addr_t <= number;
   //  content of line 1
    16'h01_00 : char_addr_t <= number;
     16'h01_01 : char_addr_t <= number;
      16'h01_02 : char_addr_t <= number;
       16'h01_03 : char_addr_t <= number;
        16'h01_04 : char_addr_t <= number;
         16'h01_05 : char_addr_t <= number;
          16'h01_06 : char_addr_t <= number;
           16'h01_07 : char_addr_t <= number;
            16'h01_08 : char_addr_t <= number;
             16'h01_09 : char_addr_t <= number;
              16'h01_0a : char_addr_t <= number;
               16'h01_0b : char_addr_t <= number;
                16'h01_0c : char_addr_t <= number;
                 16'h01_0d : char_addr_t <= number;
                  16'h01_0e : char_addr_t <= number;
                   16'h01_0f : char_addr_t <= number;
                    16'h01_10 : char_addr_t <= number;
                     16'h01_11 : char_addr_t <= number;
                      16'h01_12 : char_addr_t <= number;
                       16'h01_13 : char_addr_t <= number;
                        16'h01_14 : char_addr_t <= number;
                         16'h01_15 : char_addr_t <= number;
                          16'h01_16 : char_addr_t <= number;
                           16'h01_17 : char_addr_t <= number;
                            16'h01_18 : char_addr_t <= number;
                             16'h01_19 : char_addr_t <= number;
                              16'h01_1a : char_addr_t <= number;
                               16'h01_1b : char_addr_t <= number;
                                16'h01_1c : char_addr_t <= number;
                                 16'h01_1d : char_addr_t <= number;
                                  16'h01_1e : char_addr_t <= number;
                                   16'h01_1f : char_addr_t <= number;
                                    16'h01_20 : char_addr_t <= number;
                                     16'h01_21 : char_addr_t <= number;
                                      16'h01_22 : char_addr_t <= number;
                                       16'h01_23 : char_addr_t <= number;
                                        16'h01_24 : char_addr_t <= number;
                                         16'h01_25 : char_addr_t <= number;
                                          16'h01_26 : char_addr_t <= number;
                                           16'h01_27 : char_addr_t <= number;
   //  content of line 2
    16'h02_00 : char_addr_t <= number;
     16'h02_01 : char_addr_t <= number;
      16'h02_02 : char_addr_t <= number;
       16'h02_03 : char_addr_t <= number;
        16'h02_04 : char_addr_t <= number;
         16'h02_05 : char_addr_t <= number;
          16'h02_06 : char_addr_t <= number;
           16'h02_07 : char_addr_t <= number;
            16'h02_08 : char_addr_t <= number;
             16'h02_09 : char_addr_t <= number;
              16'h02_0a : char_addr_t <= number;
               16'h02_0b : char_addr_t <= number;
                16'h02_0c : char_addr_t <= number;
                 16'h02_0d : char_addr_t <= number;
                  16'h02_0e : char_addr_t <= number;
                   16'h02_0f : char_addr_t <= number;
                    16'h02_10 : char_addr_t <= number;
                     16'h02_11 : char_addr_t <= number;
                      16'h02_12 : char_addr_t <= number;
                       16'h02_13 : char_addr_t <= number;
                        16'h02_14 : char_addr_t <= number;
                         16'h02_15 : char_addr_t <= number;
                          16'h02_16 : char_addr_t <= number;
                           16'h02_17 : char_addr_t <= number;
                            16'h02_18 : char_addr_t <= number;
                             16'h02_19 : char_addr_t <= number;
                              16'h02_1a : char_addr_t <= number;
                               16'h02_1b : char_addr_t <= number;
                                16'h02_1c : char_addr_t <= number;
                                 16'h02_1d : char_addr_t <= number;
                                  16'h02_1e : char_addr_t <= number;
                                   16'h02_1f : char_addr_t <= number;
                                    16'h02_20 : char_addr_t <= number;
                                     16'h02_21 : char_addr_t <= number;
                                      16'h02_22 : char_addr_t <= number;
                                       16'h02_23 : char_addr_t <= number;
                                        16'h02_24 : char_addr_t <= number;
                                         16'h02_25 : char_addr_t <= number;
                                          16'h02_26 : char_addr_t <= number;
                                           16'h02_27 : char_addr_t <= number;
   //  content of line 3
    16'h03_00 : char_addr_t <= number;
     16'h03_01 : char_addr_t <= number;
      16'h03_02 : char_addr_t <= number;
       16'h03_03 : char_addr_t <= number;
        16'h03_04 : char_addr_t <= number;
         16'h03_05 : char_addr_t <= number;
          16'h03_06 : char_addr_t <= number;
           16'h03_07 : char_addr_t <= number;
            16'h03_08 : char_addr_t <= number;
             16'h03_09 : char_addr_t <= number;
              16'h03_0a : char_addr_t <= number;
               16'h03_0b : char_addr_t <= number;
                16'h03_0c : char_addr_t <= number;
                 16'h03_0d : char_addr_t <= number;
                  16'h03_0e : char_addr_t <= number;
                   16'h03_0f : char_addr_t <= number;
                    16'h03_10 : char_addr_t <= number;
                     16'h03_11 : char_addr_t <= number;
                      16'h03_12 : char_addr_t <= number;
                       16'h03_13 : char_addr_t <= number;
                        16'h03_14 : char_addr_t <= number;
                         16'h03_15 : char_addr_t <= number;
                          16'h03_16 : char_addr_t <= number;
                           16'h03_17 : char_addr_t <= number;
                            16'h03_18 : char_addr_t <= number;
                             16'h03_19 : char_addr_t <= number;
                              16'h03_1a : char_addr_t <= number;
                               16'h03_1b : char_addr_t <= number;
                                16'h03_1c : char_addr_t <= number;
                                 16'h03_1d : char_addr_t <= number;
                                  16'h03_1e : char_addr_t <= number;
                                   16'h03_1f : char_addr_t <= number;
                                    16'h03_20 : char_addr_t <= number;
                                     16'h03_21 : char_addr_t <= number;
                                      16'h03_22 : char_addr_t <= number;
                                       16'h03_23 : char_addr_t <= number;
                                        16'h03_24 : char_addr_t <= number;
                                         16'h03_25 : char_addr_t <= number;
                                          16'h03_26 : char_addr_t <= number;
                                           16'h03_27 : char_addr_t <= number;
   //  content of line 4
    16'h04_00 : char_addr_t <= number;
     16'h04_01 : char_addr_t <= number;
      16'h04_02 : char_addr_t <= number;
       16'h04_03 : char_addr_t <= number;
        16'h04_04 : char_addr_t <= number;
         16'h04_05 : char_addr_t <= number;
          16'h04_06 : char_addr_t <= number;
           16'h04_07 : char_addr_t <= number;
            16'h04_08 : char_addr_t <= number;
             16'h04_09 : char_addr_t <= number;
              16'h04_0a : char_addr_t <= number;
               16'h04_0b : char_addr_t <= number;
                16'h04_0c : char_addr_t <= number;
                 16'h04_0d : char_addr_t <= number;
                  16'h04_0e : char_addr_t <= number;
                   16'h04_0f : char_addr_t <= number;
                    16'h04_10 : char_addr_t <= number;
                     16'h04_11 : char_addr_t <= number;
                      16'h04_12 : char_addr_t <= number;
                       16'h04_13 : char_addr_t <= number;
                        16'h04_14 : char_addr_t <= number;
                         16'h04_15 : char_addr_t <= number;
                          16'h04_16 : char_addr_t <= number;
                           16'h04_17 : char_addr_t <= number;
                            16'h04_18 : char_addr_t <= number;
                             16'h04_19 : char_addr_t <= number;
                              16'h04_1a : char_addr_t <= number;
                               16'h04_1b : char_addr_t <= number;
                                16'h04_1c : char_addr_t <= number;
                                 16'h04_1d : char_addr_t <= number;
                                  16'h04_1e : char_addr_t <= number;
                                   16'h04_1f : char_addr_t <= number;
                                    16'h04_20 : char_addr_t <= number;
                                     16'h04_21 : char_addr_t <= number;
                                      16'h04_22 : char_addr_t <= number;
                                       16'h04_23 : char_addr_t <= number;
                                        16'h04_24 : char_addr_t <= number;
                                         16'h04_25 : char_addr_t <= number;
                                          16'h04_26 : char_addr_t <= number;
                                           16'h04_27 : char_addr_t <= number;
   //  content of line 5
    16'h05_00 : char_addr_t <= number;
     16'h05_01 : char_addr_t <= number;
      16'h05_02 : char_addr_t <= number;
       16'h05_03 : char_addr_t <= number;
        16'h05_04 : char_addr_t <= number;
         16'h05_05 : char_addr_t <= number;
          16'h05_06 : char_addr_t <= number;
           16'h05_07 : char_addr_t <= number;
            16'h05_08 : char_addr_t <= number;
             16'h05_09 : char_addr_t <= number;
              16'h05_0a : char_addr_t <= number;
               16'h05_0b : char_addr_t <= number;
                16'h05_0c : char_addr_t <= number;
                 16'h05_0d : char_addr_t <= number;
                  16'h05_0e : char_addr_t <= number;
                   16'h05_0f : char_addr_t <= number;
                    16'h05_10 : char_addr_t <= number;
                     16'h05_11 : char_addr_t <= number;
                      16'h05_12 : char_addr_t <= number;
                       16'h05_13 : char_addr_t <= number;
                        16'h05_14 : char_addr_t <= number;
                         16'h05_15 : char_addr_t <= number;
                          16'h05_16 : char_addr_t <= number;
                           16'h05_17 : char_addr_t <= number;
                            16'h05_18 : char_addr_t <= number;
                             16'h05_19 : char_addr_t <= number;
                              16'h05_1a : char_addr_t <= number;
                               16'h05_1b : char_addr_t <= number;
                                16'h05_1c : char_addr_t <= number;
                                 16'h05_1d : char_addr_t <= number;
                                  16'h05_1e : char_addr_t <= number;
                                   16'h05_1f : char_addr_t <= number;
                                    16'h05_20 : char_addr_t <= number;
                                     16'h05_21 : char_addr_t <= number;
                                      16'h05_22 : char_addr_t <= number;
                                       16'h05_23 : char_addr_t <= number;
                                        16'h05_24 : char_addr_t <= number;
                                         16'h05_25 : char_addr_t <= number;
                                          16'h05_26 : char_addr_t <= number;
                                           16'h05_27 : char_addr_t <= number;
   //  content of line 6
    16'h06_00 : char_addr_t <= number;
     16'h06_01 : char_addr_t <= number;
      16'h06_02 : char_addr_t <= number;
       16'h06_03 : char_addr_t <= number;
        16'h06_04 : char_addr_t <= number;
         16'h06_05 : char_addr_t <= number;
          16'h06_06 : char_addr_t <= number;
           16'h06_07 : char_addr_t <= number;
            16'h06_08 : char_addr_t <= number;
             16'h06_09 : char_addr_t <= number;
              16'h06_0a : char_addr_t <= number;
               16'h06_0b : char_addr_t <= number;
                16'h06_0c : char_addr_t <= number;
                 16'h06_0d : char_addr_t <= number;
                  16'h06_0e : char_addr_t <= number;
                   16'h06_0f : char_addr_t <= number;
                    16'h06_10 : char_addr_t <= number;
                     16'h06_11 : char_addr_t <= number;
                      16'h06_12 : char_addr_t <= number;
                       16'h06_13 : char_addr_t <= number;
                        16'h06_14 : char_addr_t <= number;
                         16'h06_15 : char_addr_t <= number;
                          16'h06_16 : char_addr_t <= number;
                           16'h06_17 : char_addr_t <= number;
                            16'h06_18 : char_addr_t <= number;
                             16'h06_19 : char_addr_t <= number;
                              16'h06_1a : char_addr_t <= number;
                               16'h06_1b : char_addr_t <= number;
                                16'h06_1c : char_addr_t <= number;
                                 16'h06_1d : char_addr_t <= number;
                                  16'h06_1e : char_addr_t <= number;
                                   16'h06_1f : char_addr_t <= number;
                                    16'h06_20 : char_addr_t <= number;
                                     16'h06_21 : char_addr_t <= number;
                                      16'h06_22 : char_addr_t <= number;
                                       16'h06_23 : char_addr_t <= number;
                                        16'h06_24 : char_addr_t <= number;
                                         16'h06_25 : char_addr_t <= number;
                                          16'h06_26 : char_addr_t <= number;
                                           16'h06_27 : char_addr_t <= number;
   //  content of line 7
    16'h07_00 : char_addr_t <= number;
     16'h07_01 : char_addr_t <= number;
      16'h07_02 : char_addr_t <= number;
       16'h07_03 : char_addr_t <= number;
        16'h07_04 : char_addr_t <= number;
         16'h07_05 : char_addr_t <= number;
          16'h07_06 : char_addr_t <= number;
           16'h07_07 : char_addr_t <= number;
            16'h07_08 : char_addr_t <= number;
             16'h07_09 : char_addr_t <= number;
              16'h07_0a : char_addr_t <= number;
               16'h07_0b : char_addr_t <= number;
                16'h07_0c : char_addr_t <= number;
                 16'h07_0d : char_addr_t <= number;
                  16'h07_0e : char_addr_t <= number;
                   16'h07_0f : char_addr_t <= number;
                    16'h07_10 : char_addr_t <= number;
                     16'h07_11 : char_addr_t <= number;
                      16'h07_12 : char_addr_t <= number;
                       16'h07_13 : char_addr_t <= number;
                        16'h07_14 : char_addr_t <= number;
                         16'h07_15 : char_addr_t <= number;
                          16'h07_16 : char_addr_t <= number;
                           16'h07_17 : char_addr_t <= number;
                            16'h07_18 : char_addr_t <= number;
                             16'h07_19 : char_addr_t <= number;
                              16'h07_1a : char_addr_t <= number;
                               16'h07_1b : char_addr_t <= number;
                                16'h07_1c : char_addr_t <= number;
                                 16'h07_1d : char_addr_t <= number;
                                  16'h07_1e : char_addr_t <= number;
                                   16'h07_1f : char_addr_t <= number;
                                    16'h07_20 : char_addr_t <= number;
                                     16'h07_21 : char_addr_t <= number;
                                      16'h07_22 : char_addr_t <= number;
                                       16'h07_23 : char_addr_t <= number;
                                        16'h07_24 : char_addr_t <= number;
                                         16'h07_25 : char_addr_t <= number;
                                          16'h07_26 : char_addr_t <= number;
                                           16'h07_27 : char_addr_t <= number;
   //  content of line 8
    16'h08_00 : char_addr_t <= number;
     16'h08_01 : char_addr_t <= number;
      16'h08_02 : char_addr_t <= number;
       16'h08_03 : char_addr_t <= number;
        16'h08_04 : char_addr_t <= number;
         16'h08_05 : char_addr_t <= number;
          16'h08_06 : char_addr_t <= number;
           16'h08_07 : char_addr_t <= number;
            16'h08_08 : char_addr_t <= number;
             16'h08_09 : char_addr_t <= number;
              16'h08_0a : char_addr_t <= number;
               16'h08_0b : char_addr_t <= number;
                16'h08_0c : char_addr_t <= number;
                 16'h08_0d : char_addr_t <= number;
                  16'h08_0e : char_addr_t <= number;
                   16'h08_0f : char_addr_t <= number;
                    16'h08_10 : char_addr_t <= number;
                     16'h08_11 : char_addr_t <= number;
                      16'h08_12 : char_addr_t <= number;
                       16'h08_13 : char_addr_t <= number;
                        16'h08_14 : char_addr_t <= number;
                         16'h08_15 : char_addr_t <= number;
                          16'h08_16 : char_addr_t <= number;
                           16'h08_17 : char_addr_t <= number;
                            16'h08_18 : char_addr_t <= number;
                             16'h08_19 : char_addr_t <= number;
                              16'h08_1a : char_addr_t <= number;
                               16'h08_1b : char_addr_t <= number;
                                16'h08_1c : char_addr_t <= number;
                                 16'h08_1d : char_addr_t <= number;
                                  16'h08_1e : char_addr_t <= number;
                                   16'h08_1f : char_addr_t <= number;
                                    16'h08_20 : char_addr_t <= number;
                                     16'h08_21 : char_addr_t <= number;
                                      16'h08_22 : char_addr_t <= number;
                                       16'h08_23 : char_addr_t <= number;
                                        16'h08_24 : char_addr_t <= number;
                                         16'h08_25 : char_addr_t <= number;
                                          16'h08_26 : char_addr_t <= number;
                                           16'h08_27 : char_addr_t <= number;
   //  content of line 9
    16'h09_00 : char_addr_t <= number;
     16'h09_01 : char_addr_t <= number;
      16'h09_02 : char_addr_t <= number;
       16'h09_03 : char_addr_t <= number;
        16'h09_04 : char_addr_t <= number;
         16'h09_05 : char_addr_t <= number;
          16'h09_06 : char_addr_t <= number;
           16'h09_07 : char_addr_t <= number;
            16'h09_08 : char_addr_t <= number;
             16'h09_09 : char_addr_t <= number;
              16'h09_0a : char_addr_t <= number;
               16'h09_0b : char_addr_t <= number;
                16'h09_0c : char_addr_t <= number;
                 16'h09_0d : char_addr_t <= number;
                  16'h09_0e : char_addr_t <= number;
                   16'h09_0f : char_addr_t <= number;
                    16'h09_10 : char_addr_t <= number;
                     16'h09_11 : char_addr_t <= number;
                      16'h09_12 : char_addr_t <= number;
                       16'h09_13 : char_addr_t <= number;
                        16'h09_14 : char_addr_t <= number;
                         16'h09_15 : char_addr_t <= number;
                          16'h09_16 : char_addr_t <= number;
                           16'h09_17 : char_addr_t <= number;
                            16'h09_18 : char_addr_t <= number;
                             16'h09_19 : char_addr_t <= number;
                              16'h09_1a : char_addr_t <= number;
                               16'h09_1b : char_addr_t <= number;
                                16'h09_1c : char_addr_t <= number;
                                 16'h09_1d : char_addr_t <= number;
                                  16'h09_1e : char_addr_t <= number;
                                   16'h09_1f : char_addr_t <= number;
                                    16'h09_20 : char_addr_t <= number;
                                     16'h09_21 : char_addr_t <= number;
                                      16'h09_22 : char_addr_t <= number;
                                       16'h09_23 : char_addr_t <= number;
                                        16'h09_24 : char_addr_t <= number;
                                         16'h09_25 : char_addr_t <= number;
                                          16'h09_26 : char_addr_t <= number;
                                           16'h09_27 : char_addr_t <= number;
   //  content of line a
    16'h0a_00 : char_addr_t <= number;
     16'h0a_01 : char_addr_t <= number;
      16'h0a_02 : char_addr_t <= number;
       16'h0a_03 : char_addr_t <= number;
        16'h0a_04 : char_addr_t <= number;
         16'h0a_05 : char_addr_t <= number;
          16'h0a_06 : char_addr_t <= number;
           16'h0a_07 : char_addr_t <= number;
            16'h0a_08 : char_addr_t <= number;
             16'h0a_09 : char_addr_t <= number;
              16'h0a_0a : char_addr_t <= number;
               16'h0a_0b : char_addr_t <= number;
                16'h0a_0c : char_addr_t <= number;
                 16'h0a_0d : char_addr_t <= number;
                  16'h0a_0e : char_addr_t <= number;
                   16'h0a_0f : char_addr_t <= number;
                    16'h0a_10 : char_addr_t <= number;
                     16'h0a_11 : char_addr_t <= number;
                      16'h0a_12 : char_addr_t <= number;
                       16'h0a_13 : char_addr_t <= number;
                        16'h0a_14 : char_addr_t <= number;
                         16'h0a_15 : char_addr_t <= number;
                          16'h0a_16 : char_addr_t <= number;
                           16'h0a_17 : char_addr_t <= number;
                            16'h0a_18 : char_addr_t <= number;
                             16'h0a_19 : char_addr_t <= number;
                              16'h0a_1a : char_addr_t <= number;
                               16'h0a_1b : char_addr_t <= number;
                                16'h0a_1c : char_addr_t <= number;
                                 16'h0a_1d : char_addr_t <= number;
                                  16'h0a_1e : char_addr_t <= number;
                                   16'h0a_1f : char_addr_t <= number;
                                    16'h0a_20 : char_addr_t <= number;
                                     16'h0a_21 : char_addr_t <= number;
                                      16'h0a_22 : char_addr_t <= number;
                                       16'h0a_23 : char_addr_t <= number;
                                        16'h0a_24 : char_addr_t <= number;
                                         16'h0a_25 : char_addr_t <= number;
                                          16'h0a_26 : char_addr_t <= number;
                                           16'h0a_27 : char_addr_t <= number;
   //  content of line b
    16'h0b_00 : char_addr_t <= number;
     16'h0b_01 : char_addr_t <= number;
      16'h0b_02 : char_addr_t <= number;
       16'h0b_03 : char_addr_t <= number;
        16'h0b_04 : char_addr_t <= number;
         16'h0b_05 : char_addr_t <= number;
          16'h0b_06 : char_addr_t <= number;
           16'h0b_07 : char_addr_t <= number;
            16'h0b_08 : char_addr_t <= number;
             16'h0b_09 : char_addr_t <= number;
              16'h0b_0a : char_addr_t <= number;
               16'h0b_0b : char_addr_t <= number;
                16'h0b_0c : char_addr_t <= number;
                 16'h0b_0d : char_addr_t <= number;
                  16'h0b_0e : char_addr_t <= number;
                   16'h0b_0f : char_addr_t <= number;
                    16'h0b_10 : char_addr_t <= number;
                     16'h0b_11 : char_addr_t <= number;
                      16'h0b_12 : char_addr_t <= number;
                       16'h0b_13 : char_addr_t <= number;
                        16'h0b_14 : char_addr_t <= number;
                         16'h0b_15 : char_addr_t <= number;
                          16'h0b_16 : char_addr_t <= number;
                           16'h0b_17 : char_addr_t <= number;
                            16'h0b_18 : char_addr_t <= number;
                             16'h0b_19 : char_addr_t <= number;
                              16'h0b_1a : char_addr_t <= number;
                               16'h0b_1b : char_addr_t <= number;
                                16'h0b_1c : char_addr_t <= number;
                                 16'h0b_1d : char_addr_t <= number;
                                  16'h0b_1e : char_addr_t <= number;
                                   16'h0b_1f : char_addr_t <= number;
                                    16'h0b_20 : char_addr_t <= number;
                                     16'h0b_21 : char_addr_t <= number;
                                      16'h0b_22 : char_addr_t <= number;
                                       16'h0b_23 : char_addr_t <= number;
                                        16'h0b_24 : char_addr_t <= number;
                                         16'h0b_25 : char_addr_t <= number;
                                          16'h0b_26 : char_addr_t <= number;
                                           16'h0b_27 : char_addr_t <= number;
   //  content of line c
    16'h0c_00 : char_addr_t <= number;
     16'h0c_01 : char_addr_t <= number;
      16'h0c_02 : char_addr_t <= number;
       16'h0c_03 : char_addr_t <= number;
        16'h0c_04 : char_addr_t <= number;
         16'h0c_05 : char_addr_t <= number;
          16'h0c_06 : char_addr_t <= number;
           16'h0c_07 : char_addr_t <= number;
            16'h0c_08 : char_addr_t <= number;
             16'h0c_09 : char_addr_t <= number;
              16'h0c_0a : char_addr_t <= number;
               16'h0c_0b : char_addr_t <= number;
                16'h0c_0c : char_addr_t <= number;
                 16'h0c_0d : char_addr_t <= number;
                  16'h0c_0e : char_addr_t <= number;
                   16'h0c_0f : char_addr_t <= number;
                    16'h0c_10 : char_addr_t <= number;
                     16'h0c_11 : char_addr_t <= number;
                      16'h0c_12 : char_addr_t <= number;
                       16'h0c_13 : char_addr_t <= number;
                        16'h0c_14 : char_addr_t <= number;
                         16'h0c_15 : char_addr_t <= number;
                          16'h0c_16 : char_addr_t <= number;
                           16'h0c_17 : char_addr_t <= number;
                            16'h0c_18 : char_addr_t <= number;
                             16'h0c_19 : char_addr_t <= number;
                              16'h0c_1a : char_addr_t <= number;
                               16'h0c_1b : char_addr_t <= number;
                                16'h0c_1c : char_addr_t <= number;
                                 16'h0c_1d : char_addr_t <= number;
                                  16'h0c_1e : char_addr_t <= number;
                                   16'h0c_1f : char_addr_t <= number;
                                    16'h0c_20 : char_addr_t <= number;
                                     16'h0c_21 : char_addr_t <= number;
                                      16'h0c_22 : char_addr_t <= number;
                                       16'h0c_23 : char_addr_t <= number;
                                        16'h0c_24 : char_addr_t <= number;
                                         16'h0c_25 : char_addr_t <= number;
                                          16'h0c_26 : char_addr_t <= number;
                                           16'h0c_27 : char_addr_t <= number;
   //  content of line d
    16'h0d_00 : char_addr_t <= number;
     16'h0d_01 : char_addr_t <= number;
      16'h0d_02 : char_addr_t <= number;
       16'h0d_03 : char_addr_t <= number;
        16'h0d_04 : char_addr_t <= number;
         16'h0d_05 : char_addr_t <= number;
          16'h0d_06 : char_addr_t <= number;
           16'h0d_07 : char_addr_t <= number;
            16'h0d_08 : char_addr_t <= number;
             16'h0d_09 : char_addr_t <= number;
              16'h0d_0a : char_addr_t <= number;
               16'h0d_0b : char_addr_t <= number;
                16'h0d_0c : char_addr_t <= number;
                 16'h0d_0d : char_addr_t <= number;
                  16'h0d_0e : char_addr_t <= number;
                   16'h0d_0f : char_addr_t <= number;
                    16'h0d_10 : char_addr_t <= number;
                     16'h0d_11 : char_addr_t <= number;
                      16'h0d_12 : char_addr_t <= number;
                       16'h0d_13 : char_addr_t <= number;
                        16'h0d_14 : char_addr_t <= number;
                         16'h0d_15 : char_addr_t <= number;
                          16'h0d_16 : char_addr_t <= number;
                           16'h0d_17 : char_addr_t <= number;
                            16'h0d_18 : char_addr_t <= number;
                             16'h0d_19 : char_addr_t <= number;
                              16'h0d_1a : char_addr_t <= number;
                               16'h0d_1b : char_addr_t <= number;
                                16'h0d_1c : char_addr_t <= number;
                                 16'h0d_1d : char_addr_t <= number;
                                  16'h0d_1e : char_addr_t <= number;
                                   16'h0d_1f : char_addr_t <= number;
                                    16'h0d_20 : char_addr_t <= number;
                                     16'h0d_21 : char_addr_t <= number;
                                      16'h0d_22 : char_addr_t <= number;
                                       16'h0d_23 : char_addr_t <= number;
                                        16'h0d_24 : char_addr_t <= number;
                                         16'h0d_25 : char_addr_t <= number;
                                          16'h0d_26 : char_addr_t <= number;
                                           16'h0d_27 : char_addr_t <= number;
   //  content of line e
    16'h0e_00 : char_addr_t <= number;
     16'h0e_01 : char_addr_t <= number;
      16'h0e_02 : char_addr_t <= number;
       16'h0e_03 : char_addr_t <= number;
        16'h0e_04 : char_addr_t <= number;
         16'h0e_05 : char_addr_t <= number;
          16'h0e_06 : char_addr_t <= number;
           16'h0e_07 : char_addr_t <= number;
            16'h0e_08 : char_addr_t <= number;
             16'h0e_09 : char_addr_t <= number;
              16'h0e_0a : char_addr_t <= number;
               16'h0e_0b : char_addr_t <= number;
                16'h0e_0c : char_addr_t <= number;
                 16'h0e_0d : char_addr_t <= number;
                  16'h0e_0e : char_addr_t <= number;
                   16'h0e_0f : char_addr_t <= number;
                    16'h0e_10 : char_addr_t <= number;
                     16'h0e_11 : char_addr_t <= number;
                      16'h0e_12 : char_addr_t <= number;
                       16'h0e_13 : char_addr_t <= number;
                        16'h0e_14 : char_addr_t <= number;
                         16'h0e_15 : char_addr_t <= number;
                          16'h0e_16 : char_addr_t <= number;
                           16'h0e_17 : char_addr_t <= number;
                            16'h0e_18 : char_addr_t <= number;
                             16'h0e_19 : char_addr_t <= number;
                              16'h0e_1a : char_addr_t <= number;
                               16'h0e_1b : char_addr_t <= number;
                                16'h0e_1c : char_addr_t <= number;
                                 16'h0e_1d : char_addr_t <= number;
                                  16'h0e_1e : char_addr_t <= number;
                                   16'h0e_1f : char_addr_t <= number;
                                    16'h0e_20 : char_addr_t <= number;
                                     16'h0e_21 : char_addr_t <= number;
                                      16'h0e_22 : char_addr_t <= number;
                                       16'h0e_23 : char_addr_t <= number;
                                        16'h0e_24 : char_addr_t <= number;
                                         16'h0e_25 : char_addr_t <= number;
                                          16'h0e_26 : char_addr_t <= number;
                                           16'h0e_27 : char_addr_t <= number;
   //  line f does not exist, can not be displayed with 2x resolution
     default : char_addr_t <= xxx;
   endcase

   //-------------------------------------------
   // mux for font ROM addresses and rgb
   //-------------------------------------------
   always @*
   begin
      if (ascii_on)
         begin
            char_addr = char_addr_t;
            row_addr  = row_addr_t;
            bit_addr  = bit_addr_t;
//            if      ((font_bit) && (char_addr_t < 8'h30)) // 4-bit hex   values
            if      ((font_bit) && (char_addr_t < 8'h10)) // 4-bit hex   values
                  text_4x_rgb8 = 8'b111_111_11; // white, bright
            else if ((font_bit) && (char_addr_t > 8'h7f)) // 8-bit other values
                  text_4x_rgb8 = 8'b001_111_01; // mostly green
            else if  (font_bit)                           // 7-bit ascii values
                  text_4x_rgb8 = 8'b001_001_11; // mostly blue
                                                          // else is default set below
            else  text_4x_rgb8 = 8'b000_000_00; // block background, black = clear
         end
   end

   assign text_4x_on = ((char_addr_t==xxx) || (text_4x_rgb8==8'h00)) ? 1'b0 : 1'b1;

   //-------------------------------------------
   // font rom interface
   //-------------------------------------------
   // Translate hexidecimal or ascii input to ascii output.
   hex_or_ascii   ASCII_Translation
     (.hex_in(char_addr), .ascii_out(char_addr_tran));

   assign rom_addr = {char_addr_tran[6:0], row_addr}; // msb of ascii not used
   assign font_bit = font_word[~bit_addr];

   // instantiate font ROM
   font_rom5 ASCII_FONT
      (.clk(clk), .address(rom_addr), .data(font_word));

endmodule

////////////////////////////////////////////////////////////////////////////////
// added suggestions to improve coding methods
/* sources:
 \docs\usenglish\books\docs\sim sim.pdf dated 5/17/2006 pages 70-73
  and from Language Template.
Unintended Latches
Synthesizers infer latches from incomplete conditional expressions, such as:
? An intended register without a rising edge or falling edge construct
? An if statement without an else clause
? A case statement without a default

always @ *
  if (GATE)
  Q = DATA;  // Harvey observes blocking used here

Converting Latch to D Register

always @ (posedge CLK)
    Q <= DATA;  // Harvey observes non-blocking used here

Converting Latch to a Logic Gate

always @ (GATE or DATA)
    if (GATE)
      Q <= DATA;  // Harvey observes non-blocking used here
    else
      Q <= 1'b0;

always @ (GATE or DATA)
    case (GATE)
      1'b1  : Q <= DATA;  // Harvey observes non-blocking used here
    default : Q <= 1'b0;

// comments from sim.pdf pages 75-77 and Language Template
Using Clock Enable Pin Instead of Gated Clocks

wire   IRWrite_clk;
assign IRWrite_clk = IRWrite & clk;
// Converting the above Gated Clock to the below Clock Enable; wire to reg.
reg    IRWrite_clk;
always @ (posedge clk)
    if (IRWrite)
      IRWrite_clk <= IRWrite;
    else
      IRWrite_clk <= 1'b0;

*/
