////////////////////////////////////////////////////////////////////////////////
// Module name: vga_layers15Jly11.v
// Demonstrate combining of various VGA signals in layers.
// (see "rgb multiplexing circuit" near end of this file)
// SW[0]through SW[3] may be used to enable some layers.
//
// Rev 05,10 Sep 2009
// Rev 06 Aug 2010 show how -> added items in sensitivity list to avoid warnings.
// Rev 07 Dec 2010 keep display always active (reset not turn off display)
//     replaced box_40x30 with ROM2k8bit_40x30box, same content, no block rams
// Rev 25 July 2011 combined methods learned
////////////////////////////////////////////////////////////////////////////////
module vga_layers15Jly11
  (Master_clk, reset,
//   SW,
//   rectangle01,
//   rectangle02,
//   stopkey, ascii_kb_tran, arrow,
   number8,
   cur40x15_y_x,
   HSYNC, VSYNC, RGB);

   input         Master_clk, reset; // system clock plus reset
//   input   [3:0] SW;
//   input  [47:0] rectangle01; // {start_x, start_y, width, height, color}
//   input  [47:0] rectangle02; // {start_x, start_y, width, height, color}
   input   [7:0] number8;
//   input         stopkey;
//   input   [7:0] ascii_kb_tran;
//   input   [5:0] arrow; // cursor direction, scale, shift keys
   output [15:0] cur40x15_y_x;
   output        HSYNC, VSYNC;
   output  [7:0] RGB;

   // signal declaration
   reg     [7:0] rgb_next8;

   // instantiate video synchronization module, needed wires first
   wire    [7:0] pre_RGB;
   wire    [9:0] pixel_x, pixel_y;
   //
   vga_sync_hw2  VH_SYNC
   //(.Master_clk(Master_clk), .reset(reset), // not needed
     (.Master_clk(Master_clk), .reset(1'b0), // keep display always active
      .pre_RGB(pre_RGB), .RGB(RGB),
      .hsync(HSYNC), .vsync(VSYNC),
      .video_on(), .p_tick(),
      .pixel_x(pixel_x), .pixel_y(pixel_y));

   // instantiate ascii text module, needed wires first
   // ascii character display in 40 by 15 array
   wire    [7:0] text_40x15_rgb8P;
   wire          text_40x15_on;
   //
   text_40x15a  TEXT_40x15_P
     (.clk(Master_clk), .number(number8),
      .pix_x(pixel_x), .pix_y(pixel_y),
      .cur40x15_y_x(cur40x15_y_x),
      .text_4x_on(text_40x15_on), .text_4x_rgb8(text_40x15_rgb8P));

   // instantiate boxes array module, needed wires first
   // 40_x by 30_y boxes array
   wire   [10:0] AdrG;
   wire          boxes_on;
   wire    [2:0] boxes_rgb3;
   wire    [7:0] boxes_rgb8;
   assign AdrG = {pixel_y[8:4],pixel_x[9:4]};
   //
   // box_40x30cpu4  BOXES_40x30  // replaced box_40x30cpu4.v with ROM2k8bit_40x30box.v
   //   (.address(AdrG), .boxes_on(boxes_on), .rgb3(boxes_rgb3), .rgb8(boxes_rgb8));
   ROM2k8bit_40x30box  BOXES_40x30
     (.clk(Master_clk), .address(AdrG), .boxes_on(boxes_on), .data(), .rgb8(boxes_rgb8));

//   // instantiate a rectangle module, needed wires first, short form of map
//   wire          rect_01_on;
//   wire    [7:0] rect_01_Color;
//   //
//   various_rect  RECT_01
//     (Master_clk, pixel_x, pixel_y,
//      rectangle01[47:38], rectangle01[37:28], // rect_01_start_x, rect_01_start_y
//      rectangle01[27:18], rectangle01[17:08], // rect_01_width,   rect_01_height
//      rectangle01[07:00],                     // rect_01_ColorIn
//      rect_01_on, rect_01_Color);

//   // instantiate a rectangle module, needed wires first, short form of map
//   wire          rect_02_on;
//   wire    [7:0] rect_02_Color;
//   //
//   various_rect  RECT_02
//     (Master_clk, pixel_x, pixel_y,
//      rectangle02[47:38], rectangle02[37:28], // rect_02_start_x, rect_02_start_y
//      rectangle02[27:18], rectangle02[17:08], // rect_02_width,   rect_02_height
//      rectangle02[07:00],                     // rect_02_ColorIn
//      rect_02_on, rect_02_Color);

   // The following can enable various images and is optional, is not required.
   // To try, uncomment lines after HERE and before THERE, then copy all of the
   // files located in the IMAGE_ROM folder to this project using
   // Add Copy of Source, then uncomment the desired line sets in the
   // rgb multiplexing circuit area (at bottom of this file).

// HERE
//
//   // instantiate ROM module, needed wires first
//   // Digilent Logo, a triangle that fills most of monitor
//   // ROM content 64x64 resolution
//   // 8 colors, vhdl
//   wire    [2:0] outRed1, outGreen1;
//   wire    [1:0] outBlue1;
//   wire   [11:0] Adr1;
//   wire    [7:0] rom1_rgb8;
//   wire          rom1_on;
//   assign Adr1 = {pixel_y[8:3],pixel_x[8:3]}; // nearly full screen
//   //
//   VideoRomNoText  ROM1_LOGO
//     (.outRed(outRed1), .outGreen(outGreen1), .outBlue(outBlue1), .AdrB(Adr1));
//   assign rom1_rgb8 = {outRed1,outGreen1,outBlue1};
//   assign rom1_on = (!(8'h0 == {outRed1,outGreen1,outBlue1}) // black is off
//                         && !pixel_x[9]); // prevent display from starting over
//
//   // instantiate ROM module, needed wires first
//   // Large colorbars
//   // ROM content 64x64 resolution
//   // 8 colors, verilog
//   wire    [2:0] outRed2, outGreen2;
//   wire    [1:0] outBlue2;
//   wire   [11:0] Adr2;
//   wire    [7:0] rom2_rgb8, color8;
//   wire          rom2_on;
//   assign Adr2 = {pixel_y[8:3],pixel_x[8:3]}; // nearly full screen
//   //
//   image_rom4k_8bit_colorbars  ROM2_Bars
//     (.clk(Master_clk), .address(Adr2), .data(color8));
//   assign outRed2   = {color8[2],color8[2],color8[2]}; // colors also not correct
//   assign outGreen2 = {color8[1],color8[1],color8[1]};
//   assign outBlue2  = {color8[0],color8[0]};
//   assign rom2_rgb8 = {outRed2,outGreen2,outBlue2};
//   assign rom2_on = (!(8'h0 == {outRed2,outGreen2,outBlue2}) // black is off
//                         && !pixel_x[9]); // prevent display from starting over
//
//   // instantiate ROM module, needed wires first
//   // An image
//   // ROM content 64x64 resolution
//   // 8  colors, vhdl, for VideoRom3bit
//   // 16 colors, vhdl, for VideoRom4bit
//   wire    [2:0] outRed3, outGreen3;
//   wire    [1:0] outBlue3;
//   wire   [11:0] Adr3;
//   wire    [7:0] rom3_rgb8;
//   wire          rom3_on;
//   assign Adr3 = {pixel_y[8:3],pixel_x[8:3]}; // nearly full screen
//   //
//   VideoRom3bit  ROM3_Image // Digilent Logo, colored
//   // or
//   //VideoRom4bit  ROM3_Image // photo, poor color
//     (.outRed(outRed3), .outGreen(outGreen3), .outBlue(outBlue3), .AdrB(Adr3));
//   assign rom3_rgb8 = {outRed3,outGreen3,outBlue3};
//   assign rom3_on = (!(8'h0 == {outRed3,outGreen3,outBlue3}) // black is off
//                         && !pixel_x[9]); // prevent display from starting over
//
//   // instantiate ROM module, needed wires first
//   // ROM content 64x64 resolution (student prepared; ask Anton for help)
//   // 256 colors, verilog
//   wire   [11:0] Adr4;
//   wire    [7:0] rom4_rgb8;
//   wire          rom4_on;
//   assign Adr4 = {pixel_y[8:3],pixel_x[8:3]}; // nearly full screen
//   //
//   videoROM  ROM4 // videoROM_James_Murdock.v is a sample
//     (.clk(Master_clk), .address(Adr4), .rgbOut(rom4_rgb8));
//   assign rom4_on = (!(8'h0 == rom4_rgb8) // black is off
//                         && !pixel_x[9]); // prevent display from starting over
//
// THERE

   //=======================================================
   // rgb multiplexing circuit
   // The first signal in "else if" list is top priority,
   // the second signal is next priority, and so on.
   // Change position of 2-line "else if" set to change priority.
   // The 23, 2.4%, 1BR comments refer to resources needed for this item
   //   Number of occupied Slices = 23, is 2.4% of 960 available,
   //   Number of Block RAMs = 1 of 4 available.
   // Only 960 slices and 4 Block RAMs are available.
   //=======================================================
   always @ (Master_clk) // could add items in sensitivity list to avoid warnings
   // always @ * // this alternate eliminates one warning
   if (1'b1==1'b0) // do nothing except enable uniform "else if" statements
            begin end
   else if (text_40x15_on)             // layer to display, 60?, 6%, 1BR
            rgb_next8 = text_40x15_rgb8P;
   else if (boxes_on)                  // layer to display, 160?,16%, 0BR
            rgb_next8 = boxes_rgb8;
//   else if (rect_01_on & rect_02_on)   // layer to display, 47, 4.9%, 0BR
//            rgb_next8 = (rect_02_Color | rect_01_Color);  // combined layers
//   else if (rect_01_on)                // layer to display, 26, 2.7%, 0BR
//            rgb_next8 = rect_01_Color;
//   else if (rect_02_on & SW[0])        // layer to display, 26, 2.7%, 0BR
//            rgb_next8 = rect_02_Color;
//   else if (rom1_on & SW[0])           // layer to display, 231, 24.1%, 0BR
//            rgb_next8 = rom1_rgb8;
//   else if (rom2_on & SW[1])           // layer to display, 09, 0.9%, 1BR
//            rgb_next8 = rom2_rgb8;
//   else if (rom3_on & SW[2])           // layer to display, 248 to 927, 25.8% to 96.6%, 0BR
//            rgb_next8 = rom3_rgb8;
//   else if (rom4_on & SW[3])           // layer to display, 11, 1.1%, 2BR
//            rgb_next8 = rom4_rgb8;
   else                                // default is to display this
//            rgb_next8 = 8'b001_001_01; // blue-gray background, 31, 3.2%, 0BR
            rgb_next8 = 8'b000_000_00; // black background, 31, 3.2%, 0BR

   assign pre_RGB = rgb_next8;

endmodule
